

#
# SET-UP ---------------------------------------------------------------------------------
# 

### Clean the environment
# rm(list=ls())
# gc()
start1 = Sys.time()

### Source the '00_global.R' script with required packages and functions

if(Sys.info()[["user"]] == "wb539995"){
  # source('~/path/to/r_script/00_global.R'
}else if(Sys.info()[["user"]] == "robli"){
  source(file.path(dirname(rstudioapi::getActiveDocumentContext()$path), '00_global.R'))
}

file.copy(rstudioapi::getSourceEditorContext()$path,
          gsub('\\.R', ' - copy.R', rstudioapi::getSourceEditorContext()$path),
          overwrite = T, copy.date = T)


#
# COSTS PROCEDURES  ------------------------------------------------------------------------------
#

### Read data
cost_procedures = clean_names(fread(file.path(project_path, 'Data', 'Raw', 'Other', "costs_procedures.csv"), encoding = 'UTF-8'))


### Re-name
names(cost_procedures)[c(2, 6, 7, 9)] <- c('procedure','from', 'until', 'procedure_class')

### Adjust type of columns where necessary
cost_procedures = cost_procedures %>% rename('price' = 'hind')
cost_procedures$price = as.numeric(gsub(',', '', cost_procedures$price))
cost_procedures = cost_procedures %>% mutate(across(c(from, until), dmy))

### Rename where necessary
cost_procedures = cost_procedures %>% 
  mutate(procedure_class = dplyr::recode(procedure_class,
                                         'UURINGUD JA PROTSEDUURID' = 'Examinations and Procedures',
                                         'AMBULATOORSED VASTUVÕTUD' = 'Outpatient Admission',
                                         'VOODIPÄEVAD' = 'Bed Days',
                                         'LABORATOORSED UURINGUD' = 'Laboratory Studies',
                                         'ANESTEESIA' = 'Anesthesia',
                                         'ERIARSTIABI STATISTILINE KOOD' = 'Specialist Statistical Code',
                                         'OPERATSIOONID' = 'Operations',
                                         'PEREARSTIABI' = 'Family Physician Assistance',
                                         'HAMBARAVI' = 'Dental Care',
                                         'VERI JA VERETOOTED' = 'Blood and Blood Products',
                                         'RAVIMID' = 'Medications',
                                         'BIOLOOGILISED RAVIMID' = 'Biological Drugs',
                                         'KOMPLEKSHINNAD' = 'Complex Prices',
                                         'TRANSPORT' = 'Transport',
                                         'OPERATSIOONIAEGSED LISAVAHENDID' = 'Auxillary Operation Items',
                                         'HAMBAPROTEESID' = 'Dentures',
                                         'ISIKUKOODITA TEENUSED' = 'Services Without Personal Code',
                                         'KOOLITERVISHOID' = 'School Health',
                                         'ORTODONTIA' = 'Orthodontics',
  ))


### Remove rows from periods outside of the period of interest
cost_procedures = cost_procedures[cost_procedures$until >= dmy(01012018) | is.na(cost_procedures$until),]


### Leave only required columns
cost_procedures = cost_procedures[,c('hkkood', 'procedure', 'procedure_class', 'price', 'from', 'until')]

### Save file
# fwrite(cost_procedures, file.path(project_path, 'Data', 'Clean', 'Other', "costs_procedures.csv"))



#
# END OF CODE  ------------------------------------------------------------------------------
#